.. _api:

API Reference
=============

This API reference manual details the primary functions and object in the
`yet_another_wizz` python package ``yaw``.

.. figure:: /_static/flowchart.svg
    :figwidth: 80%
    :alt: API flowchart

    Example flowchart indicating the relationship between the most important
    public classes and functions in `yet_another_wizz` used for redshift
    estimation.


.. dropdown:: :octicon:`list-ordered;1.5em` ‎ ‎ ‎ Table of contents
    :open:
    :margin: 0
    :color: muted
    :class-title: h5

    .. toctree::
        :glob:
        :maxdepth: 1

        api/catalog
        api/config
        api/correlation
        api/redshifts
        api/cosmo_coords
        api/utils
        api/options
